.. change::
   :tags: bug, mssql
   :tickets: 4536
   :versions: 1.3.1

   A commit() is emitted after an isolation level change to SNAPSHOT, as both
   pyodbc and pymssql open an implicit transaction which blocks subsequent SQL
   from being emitted in the current transaction.
